>From 3df3e32632f8c48cebc7cd950dcc43650f77fecc Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sun, 21 Aug 2011 13:09:14 +0300
Subject: [carFl mem 53/65] Move laptop specific vars to globals

Move laptop specific variables to globals:
is_laptop, laptop_ok

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 dmi.c        |    6 +++---
 flash.h      |    2 ++
 flashrom.c   |    2 ++
 internal.c   |    7 ++-----
 programmer.h |    2 --
 5 files changed, 9 insertions(+), 10 deletions(-)

diff --git a/dmi.c b/dmi.c
index 5ab64f0..a75a4d9 100644
--- a/dmi.c
+++ b/dmi.c
@@ -164,15 +164,15 @@ void dmi_init(globals *g)
 	if (chassis_type == NULL)
 		return;
 
-	is_laptop = 2;
+	g->is_laptop = 2;
 	for (i = 0; i < ARRAY_SIZE(dmi_chassis_types); i++) {
 		if (strcasecmp(chassis_type, dmi_chassis_types[i].name) == 0) {
-			is_laptop = dmi_chassis_types[i].is_laptop;
+			g->is_laptop = dmi_chassis_types[i].is_laptop;
 			break;
 		}
 	}
 
-	switch (is_laptop) {
+	switch (g->is_laptop) {
 	case 1:
 		msg_pdbg("Laptop detected via DMI.\n");
 		break;
diff --git a/flash.h b/flash.h
index 6c4a1d5..6901288 100644
--- a/flash.h
+++ b/flash.h
@@ -300,6 +300,8 @@ struct globals {
 	enum chipbustype buses_supported;
 	char *lb_part, *lb_vendor;
 	int partvendor_from_cbtable;
+	int is_laptop;
+	int laptop_ok;
 };
 void init_globals(globals *g);
 
diff --git a/flashrom.c b/flashrom.c
index 3bfeaa9..924ecf8 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -55,6 +55,8 @@ void init_globals(globals *g)
 	g->chip_to_probe = NULL;
 	g->lb_part = NULL, g->lb_vendor = NULL;
 	g->partvendor_from_cbtable = 0;
+	g->is_laptop = 0;
+	g->laptop_ok = 0;
 }
 
 static char *programmer_param = NULL;
diff --git a/internal.c b/internal.c
index 03165a9..e35e96f 100644
--- a/internal.c
+++ b/internal.c
@@ -124,9 +124,6 @@ int register_superio(globals *g, struct superio s)
 
 #endif
 
-int is_laptop = 0;
-int laptop_ok = 0;
-
 static int internal_shutdown(void *data)
 {
 	release_io_perms();
@@ -229,9 +226,9 @@ int internal_init(globals *g)
 	board_handle_before_laptop(g);
 
 	/* Warn if a non-whitelisted laptop is detected. */
-	if (is_laptop && !laptop_ok) {
+	if (g->is_laptop && !g->laptop_ok) {
 		msg_perr("========================================================================\n");
-		if (is_laptop == 1) {
+		if (g->is_laptop == 1) {
 			msg_perr("WARNING! You seem to be running flashrom on an unsupported laptop.\n");
 		} else {
 			msg_perr("WARNING! You may be running flashrom on an unsupported laptop. We could\n"
diff --git a/programmer.h b/programmer.h
index 98502ad..2fa8ee4 100644
--- a/programmer.h
+++ b/programmer.h
@@ -234,8 +234,6 @@ struct pci_dev *pci_card_find(globals *g, uint16_t vendor, uint16_t device,
 void get_io_perms(void);
 void release_io_perms(void);
 #if CONFIG_INTERNAL == 1
-extern int is_laptop;
-extern int laptop_ok;
 extern int force_boardenable;
 extern int force_boardmismatch;
 void probe_superio(globals *g);
-- 
1.7.6

